/**
 * Application loading and set-up.
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 */

define('app',
		['nls/i18nhelper',
		 'cordova',
		 'ember',
		 'jqueryMobile'],
		function(I18nHelper){
	
	// Checking WebStorage support
	if(typeof(Storage)!=="undefined") {
		console.log('Web Storage supported! :-)');
	} else {
		console.log('Sorry. No Web Storage. :-(');
	}
	
	// Creating the app
	var Filmeet = Ember.Application.create({
		LOG_TRANSITIONS: false
	});
	
	Filmeet.MobileBaseView = Ember.View.extend({
		attributeBindings: ['data-role']
	});
	
	Filmeet.PageView = Filmeet.MobileBaseView.extend({
		'data-role': 'page',
		didInsertElement: function(){
			var $thisView = this.$();
			$thisView.on('pageshow', function(event,ui){
				$(ui.prevPage).detach();
			});
			$.mobile.changePage($thisView);
		},
		destroy: function(){/*Nothing to do*/}
	});

	Filmeet.ToolbarBaseView = Filmeet.MobileBaseView.extend({
		attributeBindings:['data-position'],
		'data-position': function() {
			if (this.get('isFullScreen')) {
				return 'fullscreen';
			}
			if (this.get('isFixed')) {
				return 'fixed';
			}
			return '';
		}.property('isFixed', 'isFullScreen').cacheable(),
		isFixed: true,
		isFullsScreen: false
	});

	Filmeet.HeaderView = Filmeet.ToolbarBaseView.extend({
		attributeBindings:['data-theme'],
		'data-role': 'header'
	});
	
	Filmeet.ContentView = Filmeet.MobileBaseView.extend({
		'data-role': 'content',
		classNames: ['ui-content'],
		didInsertElement: function(){
			this.$().trigger('create');
		}
	});

	Filmeet.FooterView = Filmeet.MobileBaseView.extend({
		'data-role': 'footer',
		attributeBindings:['data-position']
	});

	Filmeet.ListItemView = Ember.View.extend({
		tagName: 'li',
		didInsertElement: function() {
	        this.get('parentView').$().listview('refresh');
	    }
	});

	Filmeet.ListView = Ember.CollectionView.extend({
		attributeBindings: ['data-role'],
	    'data-role':'listview',
	    tagName: 'ul',
	    itemViewClass: Filmeet.ListItemView,

	    // Observe the attached content array's length and refresh the listview on the next RunLoop tick.
	    contentLengthDidChange: function(){
	        var _self = this;
	        Ember.run.next(function() {
	        	_self.$().listview('refresh');
	        });
	    }.observes('content.length')
	});

	// Customized TextField with support for i18n through attribute 'i18nPlaceholder'
	Filmeet.TextField = Ember.TextField.extend({
		attributeBindings: ['i18nPlaceholder'],
		placeholder: function(){
			var key = this.get('i18nPlaceholder');
			var value = I18nHelper.getValueFromKey(key);
			return value;
		}.property()
	});
	
	// Customized TextArea with support for i18n through attribute 'i18nPlaceholder'
	Filmeet.TextArea = Ember.TextArea.extend({
		attributeBindings: ['i18nPlaceholder'],
		placeholder: function(){
			var key = this.get('i18nPlaceholder');
			var value = I18nHelper.getValueFromKey(key);
			return value;
		}.property()
	});
	
	// Custom helper for formatting dates
	Ember.Handlebars.registerHelper('DateFormatHelper', function(properties, options){
		var date = new Date(options.contexts[0]);
		
		var language;
		var lang;
		
		// This code is for Android devices
		// which always have 'en' as navigator.language
		if ( navigator && navigator.userAgent
		        && (language = navigator.userAgent.match(/android.*\W(\w\w)-(\w\w)\W/i))) {
			language = language[1];
		}

		if (!language && navigator) {
		        if (navigator.language) {
		        	language = navigator.language;
		        } else if (navigator.browserLanguage) {
		        	language = navigator.browserLanguage;
		        } else if (navigator.systemLanguage) {
		        	language = navigator.systemLanguage;
		        } else if (navigator.userLanguage) {
		        	language = navigator.userLanguage;
		        }
		        lang = language.substr(0, 2);
		} else if(language){
			lang = language;
		} else {
			lang = 'en';
		}
		
		var dateString = (date.getMonth()+1)+'.'+date.getDate()+'.'+date.getFullYear();
		if(lang.indexOf('es') != -1){
			dateString = date.getDate()+'.'+(date.getMonth()+1)+'.'+date.getFullYear();
		}
		
		var hours = date.getHours();
		if(hours < 10){
			hours = '0'+hours;
		}
		var minutes = date.getMinutes();
		if(minutes < 10){
			minutes = '0'+minutes;
		}
		
		return dateString+'  '+hours+':'+minutes;
	});
		
	Filmeet.StartController = Ember.Controller.extend();
	
	document.addEventListener('deviceready', function(){
		console.log('Filmeet App is READY!');
	}, false);
	
	$(document).bind('mobileinit', function() {
		$.mobile.touchOverflowEnabled = true;
	});
	
	// Exposing the app's namespace globally
	return window.Filmeet = Filmeet;
});
