/**
 * ConfigurationController.
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 */
define('controllers/configuration/configurationcontroller',
		['app',
		 'shared/keys',
		 'shared/urlcatalog',
		 'utils/validationutils',
		 'nls/i18nhelper',
		 'cordova',
		 'ember'],
		 function(Filmeet, Keys, UrlCatalog, ValidationUtils, I18nHelper){
	console.log('Defining ConfigurationController');
	Filmeet.AppConfigurationController = Ember.Controller.extend({
		// Properties
		email: null,
		password: null,
		// Functions
		save: function(){
			var self = this;
			var email = this.get('email');
			var password = this.get('password');
			
			var validEmail = ValidationUtils.isValidEmail(email);
			var emptyPassword = ValidationUtils.isEmptyOrNullString(password);
			
			if (validEmail || !emptyPassword){
				$.ajax({
					type: 'POST',
					url: UrlCatalog.get('editUser'),
					cache: false,
					data: {'email': email, 'password': password, 'hash': localStorage.getItem(Keys.authorizationHash)},
					dataType: 'json',
					success: function(data){
						if (!data.notAvailableEmail){
							console.log("Edit success");
							localStorage.setItem(Keys.authorizationHash, data.hash);
							self.transitionToRoute('app.home');
						}
						else{
							var error = I18nHelper.getValueFromKey('errorExistingEmail');
							navigator.notification.alert(error, function(){}, I18nHelper.getValueFromKey('errors'));
						}
					}
				});
			}
		},
		closeSession: function(){
			localStorage.removeItem(Keys.authorizationHash);
			localStorage.removeItem(Keys.username);
			this.transitionToRoute('login');
		}
	});
});