/**
 * Validation utilities.
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 */
define('utils/validationutils',
		function(){
	return{
		/**
		 * Function that checks if a String is empty or null.
		 * @param myString <code>String</code>
		 * @return <code>Boolean</code>
		 */
		isEmptyOrNullString: function(myString){
			try{
				if(typeof myString == 'string'){
					if(myString == null || myString == ""){
						return true;
					} else {
						return false;
					}
				} else if(myString == null){
					return true;
				} else {
					throw "InvalidArgumentType: Only String type!";
				}
			}catch (e) {
				console.error(e);
			}
		},
		/**
		 * Function that checks if an email was written correctly.
		 * @param email <code>String</code>
		 * @return <code>Boolean</code>
		 */
		isValidEmail: function(email){
			if(this.isEmptyOrNullString(email)){
				return false;
			} else {
				var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
				return re.test(email);
			}
		},
		/**
		 * Function that checks if it's a valid date.
		 * @param day <code>Number</code>
		 * @param month <code>Number</code>
		 * @param year <code>Number</code>
		 * @return <code>Boolean</code>
		 */
		isValidDate: function(day, month, year){
			// If it's April, June, September or November
			if(month == 3 || month == 5 || month == 8 || 10){
				// Check if it has 30 days or less
				return day <= 30;
			} else {
				//In other case, check if its February
				if(month == 1){
					var isLeap = new Date(year, 1, 29).getMonth() == 1
					// Check if its a leap year (February with 29 days)
					if(isLeap){
						return day <= 29;
					} else {
						return day <= 28;
					}
				} else {
					// In case of being the other months, return always true.
					return true;
				}
			}
		},
		/**
		 * Function that checks if it's a number.
		 * @param number <code>Number</code>
		 * @return <code>Boolean</code>
		 * @see http://stackoverflow.com/a/1421988
		 */
		isNumber: function (number) {
			return !isNaN(number-0);
		},
		/**
		 * Function that ensures that a date is after now.
		 * @param date <code>Date</code>
		 * @return <code>Boolean</code>
		 */
		isDateAfterNow: function(date){
			var now = new Date();
			return date.getTime() > now.getTime();
		}
	}
});